@@ -2,6 +2,11 @@ package P50Tools::Packs::RandonIp;
 
 use common::sense;
 
+{
+    no strict "vars";
+    $VERSION = '0.1';
+}
+
 #create random ip
 sub new {
 	my $ip = join (".", map int rand (256), 1..4);
